==> nextcloud-22.2.0.tgz: nextcloud/apps/user_status/l10n/sl.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Nedavna stanja",
    "In a meeting" : "Na sestanku",
    "Commuting" : "Med vožnjo",
    "Out sick" : "Na bolniški",
    "Vacationing" : "Na dopustu",
    "Working remotely" : "Delam od doma",
    "User status" : "Stanje uporabnika",
    "Clear status message after" : "Počisti sporočilo stanja po",
    "Set status" : "Nastavi stanje",
    "Online status" : "Povezano stanje",
    "Status message" : "Sporočilo stanja",
    "Clear status message" : "Počisti sporočilo stanja",
    "Set status message" : "Nastavi sporočilo stanja",
    "There was an error saving the status" : "Prišlo je do napake med shranjevanjem stanja",
    "There was an error clearing the status" : "Prišlo je do napake med odstranjevanjem stanja",
    "No recent status changes" : "Ni nedavnih sprememb stanja",
    "Away" : "Trenutno ne spremljam",
    "Do not disturb" : "Ne pustim se motiti",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "ne počisti",
    "Today" : "enkrat danes",
    "This week" : "še ta teden",
    "Online" : "Na spletu",
    "Invisible" : "Drugim neviden",
    "Offline" : "Začasno brez povezave",
    "There was an error saving the new status" : "Prišlo je do napake med shranjevanjem novega stanja",
    "30 minutes" : "po 30 minutah",
    "1 hour" : "po 1 uri",
    "4 hours" : "po 4 urah",
    "Mute all notifications" : "Utiša vsa obvestila",
    "Appear offline" : "Pokaže kot brez povezave",
    "Clear status after" : "Počisti stanje",
    "What's your status?" : "Kako želite nastaviti stanje?"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-22.2.6.tgz: nextcloud/apps/user_status/l10n/sl.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Nedavna stanja",
    "In a meeting" : "Na sestanku",
    "Commuting" : "Med vožnjo",
    "Out sick" : "Na bolniški",
    "Vacationing" : "Na dopustu",
    "Working remotely" : "Delam od doma",
    "In a call" : "V klicu",
    "User status" : "Stanje uporabnika",
    "View profile" : "Pokaži profil",
    "Clear status message after" : "Počisti sporočilo stanja po",
    "What is your status?" : "Kako želite nastaviti stanje?",
    "Set status" : "Nastavi stanje",
    "Online status" : "Povezano stanje",
    "Status message" : "Sporočilo stanja",
    "Clear status message" : "Počisti sporočilo stanja",
    "Set status message" : "Nastavi sporočilo stanja",
    "There was an error saving the status" : "Prišlo je do napake med shranjevanjem stanja",
    "There was an error clearing the status" : "Prišlo je do napake med odstranjevanjem stanja",
    "No recent status changes" : "Ni nedavnih sprememb stanja",
    "Away" : "Trenutno ne spremljam",
    "Do not disturb" : "Ne pustim se motiti",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "ne počisti",
    "Today" : "enkrat danes",
    "This week" : "še ta teden",
    "Online" : "Na spletu",
    "Invisible" : "Drugim neviden",
    "Offline" : "Začasno brez povezave",
    "There was an error saving the new status" : "Prišlo je do napake med shranjevanjem novega stanja",
    "30 minutes" : "po 30 minutah",
    "1 hour" : "po 1 uri",
    "4 hours" : "po 4 urah",
    "Mute all notifications" : "Utiša vsa obvestila",
    "Appear offline" : "Pokaže kot brez povezave",
    "What's your status?" : "Kako želite nastaviti stanje?"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
